﻿/* --------------------------------------------------------------------------------------------------------------------- */
/*  Copyright (c) AUMA Riester GmbH & Co. KG (2011-2017). All Rights Reserved */
/*  Target System: HART */
/* --------------------------------------------------------------------------------------------------------------------- */
/*  Description: */
/*  * Common macro and constants definitions  */
//
/* --------------------------------------------------------------------------------------------------------------------- */
/*   (c) Sipos Aktorik GmbH (Mathias Monse <mathias.monse@sipos.de>) */
/* --------------------------------------------------------------------------------------------------------------------- */

//---------------------------------------------------------------------------------------------------------------------
//~
//   Defining UNITS_CODES
#define  UNITS_CODE_PERCENT	units_code(0x39)  /* [Percent] "%" */
#define  UNITS_CODE_MIN	        units_code(0x32)  /* [min] "min" */
#define  UNITS_CODE_MILLISEC    "ms"
#define  UNITS_CODE_SEC	        units_code(0x33)  /* [sec] "s" */
#define  UNITS_CODE_HOUR        units_code(0x34)  /* [hr] "h" */
#define  UNITS_CODE_HERTZ   	units_code(0x26)  /* [Hz] "Hz" */
#define  UNITS_CODE_PERHOUR   	"1/h"
#define  UNITS_CODE_MILLIAMP	units_code(0x27)  /* [mA] "mA" */
#define  UNITS_CODE_AMP	        "A"
#define  UNITS_CODE_VOLT        units_code(0x3A)  /* [V] "V" */
#define  UNITS_CODE_RPM         units_code(0x77)  /* [rpm] "U/min" */
#define  UNITS_CODE_DEGREE      units_code(0x8F)  /* [degrees] "°" */
#define  UNITS_CODE_CELSIUS	units_code(0x20)  /* [degC] "°C" */
#define  UNITS_CODE_FAHRENHEIT	units_code(0x21)  /* [degF] "°F" */
#define  UNITS_CODE_NEWTONMETER	units_code(0x45)  /* [newton_meter] "Nm" */

/* --------------------------------------------------------------------------------------------------------------------- */
/* ~ */
/*    Defining Macro LVN: generate a name for a local VARIABLE for device alert messages */
/*    - Arguments:  */
/*      _VAR - ID string of device variable (e.g. PZD_123) */
/*    --> Macro prefixes _VAR with "loc_" */
#define LVN(_VAR)     loc_ ## _VAR

/* --------------------------------------------------------------------------------------------------------------------- */
/* ~ */
/*    Defining Macro L1VN: generate a name for a local VARIABLE for device alert messages */
/*    - Arguments:  */
/*      _VAR - ID string of device variable (e.g. PZD_123) */
/*    --> Macro prefixes _VAR with "loc1_" */
#define L1VN(_VAR)     loc1_ ## _VAR

/* --------------------------------------------------------------------------------------------------------------------- */
/* ~ */
/*    Defining Macro DeviceBoolVariable_RO: generate a device VARIABLE for device of boolean type */
/*      display as checkbox with LABEL text */
/*    - Arguments:  */
/*      _VAR - ID string of device variable (e.g. PZD_123) */
/*      _LEN - length in bytes (2 or 4) */
#define DeviceBoolVariable_RO(_VAR, _LEN)	VARIABLE _VAR\
{\
    LABEL	_TXT_ ## _VAR ## _;\
    HELP	_HLP_ ## _VAR ## _;\
    CLASS	DIAGNOSTIC & DYNAMIC;\
    TYPE	BIT_ENUMERATED (_LEN){{ 1, _TXT_ ## _VAR ## _ }}\
    HANDLING	READ;\
}

/* --------------------------------------------------------------------------------------------------------------------- */
/* ~ */
/*    Defining Macro DeviceBoolDisplay: generate a menu item entry for boolean type variables */
/*    - Arguments:  */
/*      _VAR - ID string of device variable (e.g. PZD_123) */
#ifdef _PDM_
#define DeviceBoolDisplay(_VAR)	_VAR (NO_LABEL)
#else
#define DeviceBoolDisplay(_VAR)	_VAR
#endif

/* --------------------------------------------------------------------------------------------------------------------- */
/* ~ */
/*    Defining Macro DeviceAlertVariable: generate a device and a local VARIABLE for device alert messages */
/*    - Arguments:  */
/*      _VAR - ID string of device variable (e.g. PZD_123) */
/*      _LEN - length in bytes (2 or 4) */
#define DeviceAlertVariable(_VAR, _LEN)	VARIABLE _VAR\
{\
    LABEL	_TXT_ ## _VAR ## _;\
    HELP	_HLP_ ## _VAR ## _;\
    CLASS	DIAGNOSTIC & DYNAMIC;\
    TYPE	UNSIGNED_INTEGER (_LEN);\
	HANDLING	READ;\
	/* TODO: POST_READ_ACTIONS{DEFINITION{LVN(_VAR)=(_VAR != 0); LVN(_VAR).VARIABLE_STATUS= _VAR.VARIABLE_STATUS; save_values();}}*/\
}\
VARIABLE  LVN(_VAR)\
{\
    LABEL	_TXT_ ## _VAR ## _;\
    HELP	_HLP_ ## _VAR ## _;\
    CLASS	LOCAL;\
    TYPE	BIT_ENUMERATED (_LEN){{ 1, _TXT_ ## _VAR ## _ }}\
	HANDLING	READ;\
	VALIDITY IF(_VAR != 0) {TRUE;}ELSE{FALSE;}\
}\
VARIABLE  L1VN(_VAR)\
{\
    LABEL	_TXT_ ## _VAR ## _;\
    HELP	_HLP_ ## _VAR ## _;\
    CLASS	LOCAL;\
    TYPE	BIT_ENUMERATED (_LEN){{ 1, _TXT_ ## _VAR ## _ }}\
	HANDLING	READ;\
}

/* --------------------------------------------------------------------------------------------------------------------- */
/* ~ */
/*    Defining Macro DeviceAlertDisplay: generate a menu item entry for device alerts */
/*    - Arguments:  */
/*      _VAR - ID string of device variable (e.g. PZD_123) */

#define DeviceAlertDisplay(_VAR)    /* TODO: _VAR (HIDDEN),*/ LVN(_VAR) (NO_LABEL)


/* --------------------------------------------------------------------------------------------------------------------- */
/* ~ */
/*    Defining Macro DeviceAlertAsBoolDisplay: generate a menu item entry for device alerts as bool */
/*    - Arguments:  */
/*      _VAR - ID string of device variable (e.g. PZD_123) */

#define DeviceAlertAsBoolDisplay(_VAR)    _VAR (HIDDEN), L1VN(_VAR) (NO_LABEL)

/* Defines for HART command transactions for AM variables */
#define TRANS_READ_PRM_4714    500
#define TRANS_READ_PRM_4715    501
#define TRANS_READ_PRM_4716    502
#define TRANS_READ_PRM_4719    503
#define TRANS_READ_PRM_4723    504
#define TRANS_READ_PRM_4725    505
#define TRANS_READ_PRM_4726    506
#define TRANS_READ_PRM_4730    507
#define TRANS_READ_PRM_4886    508
#define TRANS_READ_PRM_4887    509
#define TRANS_READ_PRM_4888    510
#define TRANS_READ_PRM_4889    511
#define TRANS_READ_PRM_4890    512
#define TRANS_READ_PRM_4891    513
#define TRANS_READ_PRM_4892    514
#define TRANS_READ_PRM_4893    515

/* --------------------------------------------------------------------------------------------------------------------- */
/* ~ */
/*    End of file */
/* --------------------------------------------------------------------------------------------------------------------- */
